#
# spec file for package netease-cloud-music-gtk
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) specCURRENT_YEAR SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rustflags '-Clink-arg=-Wl,-z,relro,-z,now'
%define _lto_cflags %{nil}
Name:           netease-cloud-music-gtk
Version:        2.4.1
Release:        1.0.2.1.sr20240803
Summary:        Linux 平台下基于 Rust + GTK4 开发的网易云音乐播放器
License:        GPL-3.0-or-later
Group:          Productivity/Multimedia/Sound/Players
URL:            https://github.com/gmg137/netease-cloud-music-gtk
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Patch1:         fix-dependencies.patch

BuildRequires:  cargo-packaging
BuildRequires:  git
BuildRequires:  meson
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(gio-2.0)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gstreamer-1.0)
BuildRequires:  pkgconfig(gstreamer-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-bad-audio-1.0)
BuildRequires:  pkgconfig(gstreamer-base-1.0)
BuildRequires:  pkgconfig(gstreamer-play-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-bad-1.0)
BuildRequires:  pkgconfig(gstreamer-plugins-base-1.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(openssl)
Requires:       gstreamer
Requires:       gstreamer-plugins-bad
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       gstreamer-plugins-ugly
Requires:       openssl

%description
netease-cloud-music-gtk 是基于 Rust + GTK4 开发的网易云音乐播放器，专为 Linux 系统打造。

%lang_package

%prep
%setup -q -a1
%autopatch -p1
mkdir .cargo
cat >.cargo/config.toml <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = 'vendor'
EOF

%build
%meson
%meson_build

%install
%meson_install
%suse_update_desktop_file -r com.gitee.gmg137.NeteaseCloudMusicGtk4 "GNOME;GTK;AudioVideo;Player;Audio;"
%find_lang %{name}4

%files
%license  COPYING
%{_bindir}/%{name}4
%{_datadir}/metainfo/com.gitee.gmg137.NeteaseCloudMusicGtk4.metainfo.xml
%{_datadir}/applications/*.desktop
%{_datadir}/glib-2.0/schemas/com.gitee.gmg137.NeteaseCloudMusicGtk4.gschema.xml
%{_datadir}/icons/hicolor/scalable/apps/com.gitee.gmg137.NeteaseCloudMusicGtk4.svg
%{_datadir}/icons/hicolor/symbolic/apps/com.gitee.gmg137.NeteaseCloudMusicGtk4-symbolic.svg
%{_datadir}/netease-cloud-music-gtk4
%{_datadir}/netease-cloud-music-gtk4/%{name}4.gresource

%files lang -f %{name}4.lang

%changelog
* Sat Aug 10 2024 gmg 137 <gmg137@live.com>
- Release version 2.4.1
  + Fix carousel image errors.
  + Fixed an error in the display of the sidebar on the discovery page.
* Wed May 29 2024 gmg 137 <gmg137@live.com>
- Release version 2.4.0
  + Add lyrics translation.
  + Add current lyrics highlighting.
  + Add delete function for playlist.
  + Add deb packaging configuration.
  + Optimize lyrics parsing.
  + Fix some minor bugs.
  + Add patch(fix-dependencies.patch).
* Mon Mar  4 2024 gmg 137 <gmg137@live.com>
- Release version 2.3.1
  + Fix mpris naming error
  + add Debian 12 install info, use atzlinux apt source
  + Fix volume adjustment desynchronization
  + Fix title bar width error
  + Fix login not working when using proxy
  + Use async_channel as message channel.
  + Update dependencies and fix conflicts
* Wed Dec 13 2023 gmg 137 <gmg137@live.com>
- Release version 2.3.0
  + Fix missing first favorite album issue
  + Fix flashback when operating frequently #230
  + Add desktop lyrics support #241
  + Optimize the logic of drag and drop progress bar
  + Optimize asynchronous task scheduling
  + Update mpris library to mpris-server
  + Optimize playback logic
  + Add simple radio function #250
  + Update dependencies
  + Fix other bugs
* Tue Dec 20 2022 gmg 137 <gmg137@live.com>
- Release version 2.2.0
  + Optimize song caching logic to reduce playback delay.
  + Show and can skip gray songs.
  + Optimize the way of image loading.
  + Fix bugs.
  + Update translation.
* Fri Nov 11 2022 gmg 137 <gmg137@live.com>
- Release version 2.1.0
  + Add login status hold.
  + Add Favorites button to the song list.
  + Add View Album button to song list.
  + Optimize song caching.
  + Fix bugs.
* Fri Oct 28 2022 gmg 137 <gmg137@live.com>
- Release version 2.0.3
  + Add volume settings.
  + Update dependency version.
  + Update translation.
  + Optimize page style.
  + Update project description.
* Mon Aug 22 2022 gmg 137 <gmg137@live.com>
- Release version 2.0.2
  + Fix setting bit rate doesn't work.
  + Add log function.
  + Updated instructions for use.
* Fri Jul  8 2022 William Brown <william.brown@suse.com>
- Remove dependency on unmaintained rust-packaging
* Sat Jul  2 2022 gmg 137 <gmg137@live.com>
- Release version 2.0.1
  + Real-time synchronization of playlist status.
  + Add automatic cache cleaning.
  + Add the function of viewing the currently playing song album.
  + Update translation.
* Tue Jun 28 2022 gmg 137 <gmg137@live.com>
- Updata to version 2.0.0
  + Refactoring with gtk4+ libadwaita.
  + Add cell phone number to login.
  + Add scan QR code to login.
  + Add web proxy support.
  + Add custom skin support.
* Fri Nov  5 2021 William Brown <william.brown@suse.com>
- Add cargo audit service to detect potential security issues
* Fri Feb 26 2021 gmg 137 <gmg137@live.com>
- Updata to version 1.2.1:
  + Change the size of cached images.
  + Repair the problem of cloud disk music playback error.
  + Optimize FM playback logic.
  + Adopt [Title-Artist.lrc] naming format for lyric files.
  + Improve Mpris support.
  + Update NetEase cloud interface, abandon LINUXAPI.
  + Change the default play and cache music to aac format..
  + Optimize icon.
  + Fix bug.
* Wed Jan 13 2021 gmg 137 <gmg137@live.com>
- Updata to version 1.2.0:
  + Add a playlist.
  + Search page automatically loads more.
  + Fix bug.
* Fri Nov  6 2020 gmg 137 <gmg137@live.com>
- Updata to version 1.1.3:
  + Add mouse back button support.
  + Fix bug.
* Sun Jun 14 2020 gmg 137 <gmg137@live.com>
- Updata to version 1.1.2:
  + Improving Mpris2 support.
  + Fix bug.
* Sun Apr 26 2020 gmg 137 <gmg137@live.com>
- Update to version 1.1.1:
  + Removing useless dependencies.
  + Add an indication of the status of the request.
  + Fix the cloud disc music playback error.
  + Remember the volume.
* Sat Mar 28 2020 gmg137 <gmg137@live.com>
- Update to version 1.1.0:
  + Replace the NetEase API implementation.
  + Replace the curl with isahc.
  + Remove useless dependencies.
  + Fix FM-related errors.
  + Streamline dependencies, optimize cache downloads.
  + fix bugs and optimize in many details.
* Thu Feb 13 2020 gmg137 <gmg137@live.com>
- Update to version 1.0.0:
  + No longer use the sled database, replace it with a standard bincode formatted file.
  + Asynchronous refactoring of network requests and file read/write.
  + Add volume control button.
  + Remember to play the loop mode.
  + Add music cloud discs.
  + Add simple lyrics.
  + Sync FM play button with playbar button status.
  + Comply with XDG catalog specifications.
  + Add cache cleanup option.
  + Add debug mode.
  + Optimize memory usage.
  + optimized interface design.
  + fix bugs and optimize with lots of detail.
